@@ -19,8 +19,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 #ifndef LALInference_h
 #define LALInference_h
@@ -60,19 +60,13 @@
 #include <lal/Window.h>
 #include <lal/LALString.h>
 #include <lal/StringInput.h>
+#include <lal/StringVector.h>
 #include <lal/LALSimInspiral.h>
 #include <lal/LALSimInspiralWaveformCache.h>
 #include <lal/LALSimNeutronStar.h>
 #include <lal/LALHashTbl.h>
 #include <lal/RealFFT.h>
-
-#include <lal/SFTutils.h>
-#include <lal/SFTfileIO.h>
 #include <lal/LALDetectors.h>
-#include <lal/LALBarycenter.h>
-#include <lal/LALInitBarycenter.h>
-#include <lal/BinaryPulsarTiming.h>
-
 
 #include <gsl/gsl_linalg.h>
 #include <gsl/gsl_errno.h>
@@ -423,12 +417,9 @@ tagLALInferenceIFOModel
 {
   LALInferenceVariables       *params; /** Parameters used when filling the buffers - template functions should copy to here */
 
-  LIGOTimeGPSVector           *times; /** Vector of time stamps for time domain data */
-
   LALDetector                 *detector; /** LALDetector structure for where this data came from */
-  EphemerisData               *ephem;  /** Ephemeris data */
-  TimeCorrectionData          *tdat; /** Einstein delay time correction data */
-  TimeCorrectionType           ttype; /** The time correction type e.g. TDB, TCB */
+
+  void                        *extraData; /** Pointer to extra detector-dependent parameters, used by pulsar analyses */
 
   REAL8TimeSeries             *timehPlus, *timehCross; /** Time series model buffers */
   COMPLEX16FrequencySeries    *freqhPlus, *freqhCross; /** Freq series model buffers */
@@ -658,7 +649,6 @@ tagLALInferenceIFOData
   REAL8FFTPlan              *margFFTPlan; /** FFT plan needed for time/time-and-phase marginalisation */
   REAL8                     fLow, fHigh;	/** integration limits for overlap integral in F-domain */
   LALDetector               *detector;          /** LALDetector structure for where this data came from */
-  BarycenterInput           *bary;              /** Barycenter information */
   LIGOTimeGPS		    epoch;              /** The epoch of this observation (the time of the first sample) */
   REAL8                     SNR;                /** IF INJECTION ONLY, E(SNR) of the injection in the detector.*/
   REAL8                     STDOF;              /** Degrees of freedom for IFO to be used in Student-T Likelihood. */
@@ -882,7 +872,8 @@ void LALInferenceMcQ2Masses(double mc, double q, double *m1, double *m2);
 
 /** Convert from q to eta (q = m2/m1, with m1 > m2). */
 void LALInferenceQ2Eta(double q, double *eta);
-
+/** Convert from dQuadMonS, dQuadMonA to dQuadMon1, dQuadMon2. */
+void LALInferencedQuadMonSdQuadMonA(REAL8 dQuadMonS, REAL8 dQuadMonA, REAL8 *dQuadMon1, REAL8 *dQuadMon2);
 /** Convert from lambdaT, dLambdaT, and eta to lambda1 and lambda2. */
 void LALInferenceLambdaTsEta2Lambdas(REAL8 lambdaT, REAL8 dLambdaT, REAL8 eta, REAL8 *lambda1, REAL8 *lambda2);
 
@@ -1176,7 +1167,7 @@ LALInferenceMCMCRunPhase* LALInferenceGetMCMCrunphase_ptrVariable(LALInferenceVa
 void LALInferenceSetMCMCrunphase_ptrVariable(LALInferenceVariables* vars,const char* name,LALInferenceMCMCRunPhase* value);
 
 #ifdef SWIG   /* SWIG interface directives */
-SWIGLAL(OWNS_THIS_STRING(const CHAR*, value));
+SWIGLAL(OWNS_THIS_ARG(const CHAR*, value));
 #endif
 
 void LALInferenceAddstringVariable(LALInferenceVariables * vars, const char * name, const CHAR* value, LALInferenceParamVaryType vary);
@@ -1186,7 +1177,7 @@ const CHAR* LALInferenceGetstringVariable(LALInferenceVariables * vars, const ch
 void LALInferenceSetstringVariable(LALInferenceVariables* vars,const char* name, const CHAR* value);
 
 #ifdef SWIG   /* SWIG interface directives */
-SWIGLAL_CLEAR(OWNS_THIS_STRING(const CHAR*, value));
+SWIGLAL_CLEAR(OWNS_THIS_ARG(const CHAR*, value));
 #endif
 
 /**
