@@ -20,8 +20,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #include <config.h>
@@ -64,10 +64,8 @@ static void semi_major_minor_from_e(double e, double *a, double *b)
 
 int XLALGetBurstApproximantFromString(const CHAR *inString)
 {
-#ifndef LAL_NDEBUG
   if ( !inString )
     XLAL_ERROR( XLAL_EFAULT );
-#endif
   if ( strstr(inString, "SineGaussianF" ) )
   {
     return SineGaussianF;
@@ -102,10 +100,8 @@ int XLALGetBurstApproximantFromString(const CHAR *inString)
 /* FIXME ORDER*/
 int XLALCheckBurstApproximantFromString(const CHAR *inString)
 {
-#ifndef LAL_NDEBUG
   if ( !inString )
     XLAL_ERROR( XLAL_EFAULT );
-#endif
   if ( strstr(inString, "Gaussian" ) )
     return 1;
   else if ( strstr(inString, "GaussianF" ) )
@@ -984,8 +980,8 @@ XLALGPSSetREAL8(&epoch, -(length - 1) / 2 * deltaT); // epoch is set to minus (3
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #include <math.h>
@@ -1265,7 +1261,7 @@ int XLALSimBurstChooseFDWaveformFromCache(
  * avoid re-computation of waveforms that differ only by simple
  * scaling relations in extrinsic parameters.
  */
-LALSimBurstWaveformCache *XLALCreateSimBurstWaveformCache()
+LALSimBurstWaveformCache *XLALCreateSimBurstWaveformCache(void)
 {
     LALSimBurstWaveformCache *cache = XLALCalloc(1,
             sizeof(LALSimBurstWaveformCache));
@@ -1482,8 +1478,8 @@ static int StoreFDHCache(LALSimBurstWaveformCache *cache, /**< the cache */
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 /**
