@@ -15,8 +15,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #include <lal/LALInferenceGenerateROQ.h>
@@ -1048,7 +1048,7 @@ REAL8 LALInferenceGenerateCOMPLEX16OrthonormalBasis(COMPLEX16Array **RBin,
     for(size_t i = 0; i < rows; i++){
       gsl_matrix_complex_get_row(ts_el, &TSview.matrix, i);
       projection_coeff = complex_weighted_dot_product(&deltaview.vector, last_rb, ts_el);
-      projection_norms2[i] += (projection_coeff.dat[0]*projection_coeff.dat[0] + projection_coeff.dat[1]*projection_coeff.dat[1]);
+      projection_norms2[i] += (GSL_REAL(projection_coeff)*GSL_REAL(projection_coeff) + GSL_IMAG(projection_coeff)*GSL_IMAG(projection_coeff));
       errors[i] = A_row_norms2[i] - projection_norms2[i];
     }
 
@@ -1102,7 +1102,8 @@ REAL8 LALInferenceGenerateCOMPLEX16OrthonormalBasis(COMPLEX16Array **RBin,
 
     /* check normalisation of generated orthogonal basis is not NaN (cause by a new orthogonal basis
       having zero residual with the current basis) - if this is the case do not add the new basis. */
-    if ( gsl_isnan(GSL_REAL(gsl_vector_complex_get(ru, dim_RB))) ){ break; }
+    gsl_complex norm = gsl_vector_complex_get(ru, dim_RB);
+    if ( gsl_isnan(GSL_REAL(norm)) ){ break; }
 
     /* add to reduced basis */
     dims->data[0] = dim_RB+1; /* add row */
