@@ -15,8 +15,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 
@@ -27,7 +27,6 @@
 #include <lal/FrequencySeries.h>
 #include <lal/Units.h>
 #include <lal/StringInput.h>
-#include <lal/LIGOLwXMLInspiralRead.h>
 #include <lal/TimeSeries.h>
 #include <lal/LALInferencePrior.h>
 #include <lal/LALInferenceTemplate.h>
@@ -36,11 +35,11 @@
 #include <lal/LALInferenceReadData.h>
 #include <lal/LALInferenceReadBurstData.h>
 #include <lal/LALInferenceInit.h>
-#include <lal/LIGOLwXMLBurstRead.h>
 #include <lal/GenerateBurst.h>
 #include <lal/LALSimBurst.h>
 #include <lal/LALInferenceCalibrationErrors.h>
 #include <lal/LALInferenceInit.h>
+#include <lal/LIGOLwXMLRead.h>
 
 
 LALInferenceModel *LALInferenceInitModelReviewBurstEvidence_unimod(LALInferenceRunState *state);
@@ -259,7 +258,7 @@ LALInferenceModel * LALInferenceInitBurstModel(LALInferenceRunState *state)
       endtime=atof(ppt->value);
   ppt=LALInferenceGetProcParamVal(commandLine,"--binj");
   if (ppt) {
-    BinjTable=XLALSimBurstTableFromLIGOLw(LALInferenceGetProcParamVal(commandLine,"--binj")->value,0,0);
+    BinjTable=XLALSimBurstTableFromLIGOLw(LALInferenceGetProcParamVal(commandLine,"--binj")->value);
     if (BinjTable){
       //burst_inj=1;
       ppt=LALInferenceGetProcParamVal(commandLine,"--event");
@@ -273,7 +272,7 @@ LALInferenceModel * LALInferenceInitBurstModel(LALInferenceRunState *state)
     }
   }
   else if ((ppt=LALInferenceGetProcParamVal(commandLine,"--inj"))){
-      SimInspiralTableFromLIGOLw(&inj_table,LALInferenceGetProcParamVal(commandLine,"--inj")->value,0,0);
+      inj_table = XLALSimInspiralTableFromLIGOLw(LALInferenceGetProcParamVal(commandLine,"--inj")->value);
       if (inj_table){
         ppt=LALInferenceGetProcParamVal(commandLine,"--event");
         if(ppt){
@@ -313,7 +312,7 @@ LALInferenceModel * LALInferenceInitBurstModel(LALInferenceRunState *state)
       char *name=strings[N];
       node=LALInferenceGetItem(&tempParams,name);
       if(node) {LALInferenceAddVariable(currentParams,node->name,node->value,node->type,node->vary); printf("pinned %s \n",node->name);}
-      else {fprintf(stderr,"Error: Cannot pin parameter %s. No such parameter found in injection!\n",node->name);}
+      else {fprintf(stderr,"Error: Cannot pin parameter %s. No such parameter found in injection!\n",name);}
     }
   }
     
