@@ -17,12 +17,11 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #include <complex.h>
-#include <assert.h>
 #include <lal/LALInferenceLikelihood.h>
 #include <lal/LALInferencePrior.h>
 #include <lal/LALInference.h>
@@ -83,9 +82,9 @@ static int get_calib_spline(LALInferenceVariables *vars, const char *ifoname, RE
   if(!*logfreqs) *logfreqs = XLALCreateREAL8Vector(npts);
   if(!*amps) *amps = XLALCreateREAL8Vector(npts);
   if(!*phases) *phases = XLALCreateREAL8Vector(npts);
-  assert((*logfreqs)->length==npts);
-  assert((*amps)->length==npts);
-  assert((*phases)->length==npts);
+  XLAL_CHECK_ABORT((*logfreqs)->length==npts);
+  XLAL_CHECK_ABORT((*amps)->length==npts);
+  XLAL_CHECK_ABORT((*phases)->length==npts);
 
   for(UINT4 i=0;i<npts;i++)
   {
@@ -348,7 +347,7 @@ static REAL8 LALInferenceFusedFreqDomainLogLikelihood(LALInferenceVariables *cur
   double ra=0.0, dec=0.0, psi=0.0, gmst=0.0;
   double GPSdouble=0.0, t0=0.0;
   LIGOTimeGPS GPSlal;
-  double chisquared;
+  //double chisquared;
   double timedelay;  /* time delay b/w iterferometer & geocenter w.r.t. sky location */
   double timeshift=0;  /* time shift (not necessarily same as above)                   */
   double deltaT, TwoDeltaToverN, deltaF, twopit=0.0, re, im, dre, dim, newRe, newIm;
@@ -582,7 +581,7 @@ static REAL8 LALInferenceFusedFreqDomainLogLikelihood(LALInferenceVariables *cur
   XLALGPSSetREAL8(&GPSlal, GPSdouble);
   gmst=XLALGreenwichMeanSiderealTime(&GPSlal);
 
-  chisquared = 0.0;
+  //chisquared = 0.0;
   REAL8 loglikelihood = 0.0;
 
   /* Reset SNR */
@@ -982,7 +981,7 @@ static REAL8 LALInferenceFusedFreqDomainLogLikelihood(LALInferenceVariables *cur
           REAL8 diffsq = creal(diff)*creal(diff)+cimag(diff)*cimag(diff);
           chisq = TwoDeltaToverN*diffsq/sigmasq;
           singleFreqBinTerm = chisq;
-          chisquared  += singleFreqBinTerm;
+          //chisquared  += singleFreqBinTerm;
           model->ifo_loglikelihoods[ifo] -= singleFreqBinTerm;
           break;
         }
@@ -991,7 +990,7 @@ static REAL8 LALInferenceFusedFreqDomainLogLikelihood(LALInferenceVariables *cur
           REAL8 diffsq = creal(diff)*creal(diff)+cimag(diff)*cimag(diff);
           chisq = TwoDeltaToverN*diffsq/sigmasq;
           singleFreqBinTerm = ((degreesOfFreedom+2.0)/2.0) * log(1.0 + chisq/degreesOfFreedom) ;
-          chisquared  += singleFreqBinTerm;
+          //chisquared  += singleFreqBinTerm;
           model->ifo_loglikelihoods[ifo] -= singleFreqBinTerm;
           break;
         }
@@ -1674,7 +1673,6 @@ REAL8 LALInferenceFastSineGaussianLogLikelihood(LALInferenceVariables *currentPa
   double ra=0.0, dec=0.0, psi=0.0, gmst=0.0;
   double GPSdouble=0.0;
   LIGOTimeGPS GPSlal;
-  double chisquared;
   double timedelay;  /* time delay b/w iterferometer & geocenter w.r.t. sky location */
   double timeshift=0;  /* time shift (not necessarily same as above)                   */
   double deltaT, TwoDeltaToverN, deltaF, twopit=0.0, re, im, dre, dim, newRe, newIm;
@@ -1733,7 +1731,6 @@ REAL8 LALInferenceFastSineGaussianLogLikelihood(LALInferenceVariables *currentPa
   XLALGPSSetREAL8(&GPSlal, GPSdouble);
   gmst=XLALGreenwichMeanSiderealTime(&GPSlal);
 
-  chisquared = 0.0;
   REAL8 loglikelihood = 0.0;
 
   /* Reset SNR */
@@ -1855,7 +1852,6 @@ REAL8 LALInferenceFastSineGaussianLogLikelihood(LALInferenceVariables *currentPa
 
       REAL8 diffsq = creal(diff)*creal(diff)+cimag(diff)*cimag(diff);
       chisq = TwoDeltaToverN*diffsq/sigmasq;
-      chisquared  += chisq;
       model->ifo_loglikelihoods[ifo] -= chisq;
     } /* End loop over freq bins */
 
