@@ -17,23 +17,23 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with with program; see the file COPYING. If not, write to the
-# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-# MA 02111-1307 USA
+# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+# MA 02110-1301 USA
 
-id = "88aec4acab9906814543426584fc6f326a91adaf"
-date = "2020-08-7 16:22:37 +0000"
+id = "572b3bef0176d352aff5bd3c60aad18afa70ea9b"
+date = "2024-08-20 15:10:40 +0000"
 branch = "None"
-tag = "lalinference-v2.0.3"
+tag = "lalinference-v4.1.7"
 if tag == "None":
     tag = None
 author = "Adam Mercer <adam.mercer@ligo.org>"
 builder = "Adam Mercer <adam.mercer@ligo.org>"
-committer = "Adam Mercer <ramercer@gmail.com>"
+committer = "Adam Mercer <adam.mercer@ligo.org>"
 status = "CLEAN: All modifications committed"
 version = id
 verbose_msg = """Branch: None
-Tag: lalinference-v2.0.3
-Id: 88aec4acab9906814543426584fc6f326a91adaf
+Tag: lalinference-v4.1.7
+Id: 572b3bef0176d352aff5bd3c60aad18afa70ea9b
 
 Builder: Adam Mercer <adam.mercer@ligo.org>
 Repository status: CLEAN: All modifications committed"""
@@ -54,9 +54,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError(onmismatch + " is an unrecognized value of onmismatch")
-    if foreign_id == "88aec4acab9906814543426584fc6f326a91adaf":
+    if foreign_id == "572b3bef0176d352aff5bd3c60aad18afa70ea9b":
         return
-    msg = "Program id (88aec4acab9906814543426584fc6f326a91adaf) does not match given id (%s)." % foreign_id
+    msg = "Program id (572b3bef0176d352aff5bd3c60aad18afa70ea9b) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError(msg)
 
