@@ -16,8 +16,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #include <stdio.h>
@@ -25,7 +25,6 @@
 #include <lal/LALInference.h>
 #include <lal/XLALError.h>
 #include <math.h>
-#include <assert.h>
 #include "LALInferenceTest.h"
 
 #define EPSILON 1e-13
