@@ -15,8 +15,8 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with with program; see the file COPYING. If not, write to the
- *  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
- *  MA  02111-1307  USA
+ *  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ *  MA  02110-1301  USA
  */
 
 #include <stdio.h>
@@ -31,7 +31,7 @@
 #include <lal/TimeSeries.h>
 #include <lal/Sequence.h>
 #include <lal/StringInput.h>
-#include <lal/LIGOLwXMLInspiralRead.h>
+#include <lal/LIGOLwXMLRead.h>
 #include <lal/LALInferenceInit.h>
 #include <lal/LALInferenceReadData.h> 
 #include <lal/LALInferenceLikelihood.h>
@@ -463,7 +463,11 @@ LALInferenceRunState *initialize(ProcessParamsTable *commandLine)
 	if (ppt != NULL)
 		randomseed = atoi(ppt->value);
 	else { /* otherwise generate "random" random seed: */
-		if ((devrandom = fopen("/dev/random","r")) == NULL) {
+		/*
+		 * Note: /dev/random can be slow after the first few accesses, which is why we're using urandom instead.
+		 * [Cryptographic safety isn't a concern here at all]
+		 */
+		if ((devrandom = fopen("/dev/urandom","r")) == NULL) {
 			gettimeofday(&tv, 0);
 			randomseed = tv.tv_sec + tv.tv_usec;
 		} 
@@ -892,8 +896,7 @@ void DataTest(void)
     }
 
     IfoPtr=runstate->data;
-	SimInspiralTable *injTable=NULL;
-	printf("Ninj: %d\n", SimInspiralTableFromLIGOLw(&injTable,LALInferenceGetProcParamVal(ppt,"--injXML")->value,0,0));
+	SimInspiralTable *injTable= XLALSimInspiralTableFromLIGOLw(LALInferenceGetProcParamVal(ppt,"--injXML")->value);
 	
 	REAL8 mc = injTable->mchirp;
 	REAL8 eta = injTable->eta;
@@ -1142,8 +1145,7 @@ void PTMCMCTest(void)
 	thread->model->templt=LALInferenceTemplateXLALSimInspiralChooseWaveform;
 	
 	
-	SimInspiralTable *injTable=NULL;
-	printf("Ninj: %d\n", SimInspiralTableFromLIGOLw(&injTable,LALInferenceGetProcParamVal(ppt,"--injXML")->value,0,0));
+	SimInspiralTable *injTable= XLALSimInspiralTableFromLIGOLw(LALInferenceGetProcParamVal(ppt,"--injXML")->value);
 	
 	REAL8 mc = injTable->mchirp;
 	REAL8 eta = injTable->eta;
